==> elixir-react-native-components-1.0.0.tgz: package/components/key/autocomplete.js <==
/* eslint-disable react/jsx-boolean-value */
import React, { useEffect, useState, useRef } from "react";
import { useFonts } from 'expo-font';
import MultiSelect from 'react-native-multiple-select';
import PropTypes from "prop-types";
import { Platform, View } from 'react-native';
import * as colors from './../../src-screens/environments/colors';
import { Styles } from "../../src-screens/Styles/eliraStyles";
import { evalStyle } from "../../helpers/util";
import TextField from '@mui/material/TextField';
import Autocomplete, { createFilterOptions } from '@mui/material/Autocomplete';
import general from "elixir-react-stateful/redux/sagas/general";
const AutoCompleteComponent = ({ meta, value, onChange, onQuery, onClear, theme, customStyle, tdlPath, path, isRTL, isLoading }) => {
  const { pv, isMandatory } = meta;
  const [currentSearchValue, setCurrentSearchValue] = useState(null);
  const [listIsOpened, setListIsOpened] = useState(false)
  const filter = createFilterOptions();
  //  const [valueWeb, setValueWeb] = useState(null);
  let [fontsLoaded] = useFonts(
    {

      'SourceSansLight': 'https://rsms.me/inter/font-files/Inter-SemiBoldItalic.otf?v=3.12'

    }
  );
  console.log("vvaaalll", value)
  console.log("vvaaalll 1", isRTL)
  useEffect(() => {
    // if (value && value.pk) {
    //   setValueWeb(value._label)
    // }
    // if (Platform.OS == "web") {
    //   if (!value) {
    //     onChange(valueWeb ? valueWeb : {});
    //   }
    // }
    if (value && value.pk && pv.length === 0) {

      onQuery(value._label);
    }
  }, [value]);
  const multiSelect = useRef(null)
  // evalStyle(customStyle, value, meta)
  let inputGroupStyle = {
    flex: 1,
    //  paddingLeft: 3,
    borderWidth: 0.4,
    borderRadius: 5,


  }
  if (customStyle) {
    inputGroupStyle = { ...inputGroupStyle, ...customStyle.inputGroupStyle }
  }


  let listContainerStyle = {
    flex: 1,
    elevation: 1,
    backgroundColor: colors.Geyser,
    paddingVertical: 5,
    borderWidth: 0.2,
    borderRadius: 2,

  }

  if (customStyle) {
    listContainerStyle = { ...listContainerStyle, ...customStyle.listContainerStyle }
  }

  let rowListStyle = {
    flex: 1,
    alignContent: 'center',
    justifyContent: 'center',
    borderColor: colors.DOVE_GRAY,
    borderWidth: 0.2,

  }
  if (customStyle) {
    rowListStyle = { ...rowListStyle, ...customStyle.rowListStyle }
  }

  let dropDownMenuStyle = {

    borderColor: 'red',
    borderRadius: 20

  }
  if (customStyle) {
    dropDownMenuStyle = { ...dropDownMenuStyle, ...customStyle.dropDownMenuStyle }

  }

  let mainWrapperStyle = {
  }
  if (customStyle) {
    mainWrapperStyle = { ...mainWrapperStyle, ...customStyle.mainWrapperStyle }

  }

  console.log("finally", isLoading)
  return (
    <>

      <View style={{ flex: 1, justifyContent: 'center' }}>
        <View style={{ flex: 1, justifyContent: 'center' }}>
          {Platform.OS == "web" &&
            <Autocomplete
              value={value && value._label || ""}
              blurOnSelect={true}
              onChange={(event, val) => {
                // val = val[0]
                console.log("vallll", val);
                // onQuery(val);
                // setCurrentSearchValue(val);
                onChange(val ? pv.find((item) => item.pk === val.pk) : {});
                // setCurrentSearchValue(null);
                setListIsOpened(false)
              }}
              onKeyDown={(e) => {
                console.log("e.keyCode", e.keyCode)
                if (e.keyCode === 9) e.preventDefault();
              }}
              filterOptions={(options, params) => {
                console.log(`options ${options} with params ${params} `)
                const filtered = filter(options, params);

                const { inputValue } = params;
                onQuery(inputValue);
                setCurrentSearchValue(inputValue);
                // Suggest the creation of a new value
                // const isExisting = options.some((option) => inputValue === option._label);
                // if (inputValue !== '' && !isExisting) {
                //   filtered.push({
                //     inputValue,
                //     _label: `Add "${inputValue}"`,
                //   });
                // }

                return filtered;
              }}
              open={listIsOpened}
              onOpen={() => {
                if (!pv || pv.length === 0) onQuery("");
                setListIsOpened(true)
              }}
              onClose={() => {
                setListIsOpened(false);
              }}
              selectOnFocus
              clearOnBlur
              handleHomeEndKeys
              id="pk"
              options={pv}
              getOptionLabel={(option) => {
                // Value selected with enter, right from the input
                if (typeof option === 'string') {
                  return option;
                }
                // Add "xxx" option created dynamically
                if (option.inputValue) {
                  return option.inputValue;
                }
                // Regular option
                return option._label;
              }}
              renderOption={(props, option) => <li {...props}>{option._label}</li>}
              sx={{ width: 300 }}
              freeSolo
              renderInput={(params) => (
                <TextField {...params} label="" />
              )}
              uniqueKey="pk"
              ref={(component) => { multiSelect.current = component }}
              style={{  width:"95%", textAlign: isRTL ? 'right' : 'left' ,marginTop:10 }}
            />
          }
          {
            Platform.OS != "web" &&
            <MultiSelect
              hideTags

              styleMainWrapper={listIsOpened ? {} : mainWrapperStyle}
              items={pv}
              uniqueKey="pk"
              ref={(component) => { multiSelect.current = component }}
              onSelectedItemsChange={(val) => {
                val = val[0]
                onChange(val ? pv.find((item) => item.pk === val) : {});
                setCurrentSearchValue(null);
                setListIsOpened(false)
              }}
              selectText={value && value._label || ""}
              onChangeInput={(query) => {
                // console.log("jkjkjdfff",query)
                onQuery(query);
                setCurrentSearchValue(query);
                setListIsOpened(false)
              }}
              onToggleList={() => {
                if (!pv || pv.length === 0) onQuery("");
                setListIsOpened(true)
              }}
              onClearSelector={() => { onClear(); setListIsOpened(false) }}
              selectedItems={[value && value.pk || value]}
              altFontFamily="AlmaraiLight"
              fontFamily="AlmaraiLight"
              itemFontSize={14}
              fontSize={Styles.fontSize}
              selectedItemTextColor={colors.Cutty_Sark}
              selectedItemIconColor={colors.Cutty_Sark}
              itemTextColor={colors.BLACK}
              displayKey="_label"
              searchInputStyle={{ flex: 1, color: colors.DARK_GRAY }}
              submitButtonColor="#CCC"
              single={true}
              // hideSubmitButton={true}
              hideDropdown={false}
              textColor={colors.text_color}
              styleTextDropdownSelected={{
                textAlign: "auto",
                fontFamily: "AlmaraiLight",
                height: "100%",
                // backgroundColor:"yellow"
              }}
              styleTextDropdown={{ fontSize: 25, fontFamily: "AlmaraiLight" }}
              styleItemsContainer={{ padding: 5 }}
              styleInputGroup={inputGroupStyle}
              styleListContainer={listContainerStyle}
              styleRowList={[rowListStyle]}

            />
          }



          <View>
            {multiSelect.current != null && multiSelect.current.getSelectedItemsExt && multiSelect.current.getSelectedItemsExt([value])}
          </View>
        </View>
      </View>



    </>
    // }
    // <AutoComplete
    //   allowClear={isMandatory === "false"}
    //   style={{ width: "100%" }}
    //   value={currentSearchValue || (value && (value._label || value._label))}
    //   showArrow
    //   onClear={onClear}
    // onSelect={(val) => {
    //   onChange(val ? pv.find((item) => item.pk === val) : {});
    //   setCurrentSearchValue(null);
    // }}
    // onSearch={(query) => {
    //   onQuery(query);
    //   setCurrentSearchValue(query);
    // }}
    // onFocus={() => {
    //   if (!pv || pv.length === 0) onQuery("");
    // }}
    //   onKeyUp={onKeyUp}
    // >
    //   {pv &&
    //     pv.map((val) => (
    //       <AutoComplete.Option key={val.pk} value={val.pk} title={val._label}>
    //         {val._label}
    //       </AutoComplete.Option>
    //     ))}
    // </AutoComplete>
  );
};

AutoCompleteComponent.propTypes = {
  meta: PropTypes.objectOf(PropTypes.any).isRequired,
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.object]),
  onChange: PropTypes.func.isRequired,
  onQuery: PropTypes.func.isRequired,
  onClear: PropTypes.func.isRequired,
  theme: PropTypes.objectOf(PropTypes.any),
  customStyle: PropTypes.objectOf(PropTypes.any)
};

AutoCompleteComponent.defaultProps = {
  value: null
};

export default AutoCompleteComponent;

==> elixir-react-native-components-1.2.0.tgz: package/components/key/autocomplete.js <==
/* eslint-disable react/jsx-boolean-value */
import React, { useEffect, useState, useRef } from "react";
import { useFonts } from 'expo-font';
import MultiSelect from 'react-native-multiple-select';
import PropTypes from "prop-types";
import { Platform, View } from 'react-native';
import * as colors from './../../src-screens/environments/colors';
import { Styles } from "../../src-screens/Styles/eliraStyles";
import { evalStyle } from "../../helpers/util";
import TextField from '@mui/material/TextField';
import Autocomplete, { createFilterOptions } from '@mui/material/Autocomplete';
import general from "@muhammadz/elixir-react-stateful/redux/sagas/general";
const AutoCompleteComponent = ({ meta, value, onChange, onQuery, onClear, theme, customStyle, tdlPath, path, isRTL, isLoading }) => {
  const { pv, isMandatory } = meta;
  const [currentSearchValue, setCurrentSearchValue] = useState(null);
  const [listIsOpened, setListIsOpened] = useState(false)
  const filter = createFilterOptions();
  //  const [valueWeb, setValueWeb] = useState(null);
  let [fontsLoaded] = useFonts(
    {

      'SourceSansLight': 'https://rsms.me/inter/font-files/Inter-SemiBoldItalic.otf?v=3.12'

    }
  );
  console.log("vvaaalll", value)
  console.log("vvaaalll 1", isRTL)
  useEffect(() => {
    // if (value && value.pk) {
    //   setValueWeb(value._label)
    // }
    // if (Platform.OS == "web") {
    //   if (!value) {
    //     onChange(valueWeb ? valueWeb : {});
    //   }
    // }
    if (value && value.pk && pv.length === 0) {

      onQuery(value._label);
    }
  }, [value]);
  const multiSelect = useRef(null)
  // evalStyle(customStyle, value, meta)
  let inputGroupStyle = {
    flex: 1,
    //  paddingLeft: 3,
    borderWidth: 0.4,
    borderRadius: 5,


  }
  if (customStyle) {
    inputGroupStyle = { ...inputGroupStyle, ...customStyle.inputGroupStyle }
  }


  let listContainerStyle = {
    flex: 1,
    elevation: 1,
    backgroundColor: colors.Geyser,
    paddingVertical: 5,
    borderWidth: 0.2,
    borderRadius: 2,

  }

  if (customStyle) {
    listContainerStyle = { ...listContainerStyle, ...customStyle.listContainerStyle }
  }

  let rowListStyle = {
    flex: 1,
    alignContent: 'center',
    justifyContent: 'center',
    borderColor: colors.DOVE_GRAY,
    borderWidth: 0.2,

  }
  if (customStyle) {
    rowListStyle = { ...rowListStyle, ...customStyle.rowListStyle }
  }

  let dropDownMenuStyle = {

    borderColor: 'red',
    borderRadius: 20

  }
  if (customStyle) {
    dropDownMenuStyle = { ...dropDownMenuStyle, ...customStyle.dropDownMenuStyle }

  }

  let mainWrapperStyle = {
  }
  if (customStyle) {
    mainWrapperStyle = { ...mainWrapperStyle, ...customStyle.mainWrapperStyle }

  }

  console.log("finally", isLoading)
  return (
    <>

      <View style={{ flex: 1, justifyContent: 'center' }}>
        <View style={{ flex: 1, justifyContent: 'center' }}>
          {Platform.OS == "web" &&
            <Autocomplete
              value={value && value._label || ""}
              blurOnSelect={true}
              onChange={(event, val) => {
                // val = val[0]
                console.log("vallll", val);
                // onQuery(val);
                // setCurrentSearchValue(val);
                onChange(val ? pv.find((item) => item.pk === val.pk) : {});
                // setCurrentSearchValue(null);
                setListIsOpened(false)
              }}
              onKeyDown={(e) => {
                console.log("e.keyCode", e.keyCode)
                if (e.keyCode === 9) e.preventDefault();
              }}
              filterOptions={(options, params) => {
                console.log(`options ${options} with params ${params} `)
                const filtered = filter(options, params);

                const { inputValue } = params;
                onQuery(inputValue);
                setCurrentSearchValue(inputValue);
                // Suggest the creation of a new value
                // const isExisting = options.some((option) => inputValue === option._label);
                // if (inputValue !== '' && !isExisting) {
                //   filtered.push({
                //     inputValue,
                //     _label: `Add "${inputValue}"`,
                //   });
                // }

                return filtered;
              }}
              open={listIsOpened}
              onOpen={() => {
                if (!pv || pv.length === 0) onQuery("");
                setListIsOpened(true)
              }}
              onClose={() => {
                setListIsOpened(false);
              }}
              selectOnFocus
              clearOnBlur
              handleHomeEndKeys
              id="pk"
              options={pv}
              getOptionLabel={(option) => {
                // Value selected with enter, right from the input
                if (typeof option === 'string') {
                  return option;
                }
                // Add "xxx" option created dynamically
                if (option.inputValue) {
                  return option.inputValue;
                }
                // Regular option
                return option._label;
              }}
              renderOption={(props, option) => <li {...props}>{option._label}</li>}
              sx={{ width: 300 }}
              freeSolo
              renderInput={(params) => (
                <TextField {...params} label="" />
              )}
              uniqueKey="pk"
              ref={(component) => { multiSelect.current = component }}
              style={{  width:"95%", textAlign: isRTL ? 'right' : 'left' ,marginTop:10 }}
            />
          }
          {
            Platform.OS != "web" &&
            <MultiSelect
              hideTags

              styleMainWrapper={listIsOpened ? {} : mainWrapperStyle}
              items={pv}
              uniqueKey="pk"
              ref={(component) => { multiSelect.current = component }}
              onSelectedItemsChange={(val) => {
                val = val[0]
                onChange(val ? pv.find((item) => item.pk === val) : {});
                setCurrentSearchValue(null);
                setListIsOpened(false)
              }}
              selectText={value && value._label || ""}
              onChangeInput={(query) => {
                // console.log("jkjkjdfff",query)
                onQuery(query);
                setCurrentSearchValue(query);
                setListIsOpened(false)
              }}
              onToggleList={() => {
                if (!pv || pv.length === 0) onQuery("");
                setListIsOpened(true)
              }}
              onClearSelector={() => { onClear(); setListIsOpened(false) }}
              selectedItems={[value && value.pk || value]}
              altFontFamily="AlmaraiLight"
              fontFamily="AlmaraiLight"
              itemFontSize={14}
              fontSize={Styles.fontSize}
              selectedItemTextColor={colors.Cutty_Sark}
              selectedItemIconColor={colors.Cutty_Sark}
              itemTextColor={colors.BLACK}
              displayKey="_label"
              searchInputStyle={{ flex: 1, color: colors.DARK_GRAY }}
              submitButtonColor="#CCC"
              single={true}
              // hideSubmitButton={true}
              hideDropdown={false}
              textColor={colors.text_color}
              styleTextDropdownSelected={{
                textAlign: "auto",
                fontFamily: "AlmaraiLight",
                height: "100%",
                // backgroundColor:"yellow"
              }}
              styleTextDropdown={{ fontSize: 25, fontFamily: "AlmaraiLight" }}
              styleItemsContainer={{ padding: 5 }}
              styleInputGroup={inputGroupStyle}
              styleListContainer={listContainerStyle}
              styleRowList={[rowListStyle]}

            />
          }



          <View>
            {multiSelect.current != null && multiSelect.current.getSelectedItemsExt && multiSelect.current.getSelectedItemsExt([value])}
          </View>
        </View>
      </View>



    </>
    // }
    // <AutoComplete
    //   allowClear={isMandatory === "false"}
    //   style={{ width: "100%" }}
    //   value={currentSearchValue || (value && (value._label || value._label))}
    //   showArrow
    //   onClear={onClear}
    // onSelect={(val) => {
    //   onChange(val ? pv.find((item) => item.pk === val) : {});
    //   setCurrentSearchValue(null);
    // }}
    // onSearch={(query) => {
    //   onQuery(query);
    //   setCurrentSearchValue(query);
    // }}
    // onFocus={() => {
    //   if (!pv || pv.length === 0) onQuery("");
    // }}
    //   onKeyUp={onKeyUp}
    // >
    //   {pv &&
    //     pv.map((val) => (
    //       <AutoComplete.Option key={val.pk} value={val.pk} title={val._label}>
    //         {val._label}
    //       </AutoComplete.Option>
    //     ))}
    // </AutoComplete>
  );
};

AutoCompleteComponent.propTypes = {
  meta: PropTypes.objectOf(PropTypes.any).isRequired,
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.object]),
  onChange: PropTypes.func.isRequired,
  onQuery: PropTypes.func.isRequired,
  onClear: PropTypes.func.isRequired,
  theme: PropTypes.objectOf(PropTypes.any),
  customStyle: PropTypes.objectOf(PropTypes.any)
};

AutoCompleteComponent.defaultProps = {
  value: null
};

export default AutoCompleteComponent;
